Note that the tests in this directory are currently in the form of scripts.
This makes them easy to run for interactive testing with "ipython -i"
during development, but doesn't play nice with pytest.

test_runner.py runs these scripts as via unittest


TODO:
Add ordinary unit tests, too
